<?php
/*
Plugin Name: Yard Plugin
Description: Displays a Yard calendar in your WordPress installation. Click "Manage your calendar" for the documentation.
Version: 1.01
Author: Team Yard | <a href="https://www.yard.global/events/integrate/plugin/" target="_blank">Manage your calendar</a>
Author URI: https://www.yard.global
*/

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}


// Enqueue plugin CSS
function yard_enqueue_styles() {
    wp_enqueue_style('yard-plugin-style', plugin_dir_url(__FILE__) . 'yard-plugin.css');
}
add_action('wp_enqueue_scripts', 'yard_enqueue_styles');


function yard_fetch_events($params) {
    $remote_url = 'https://www.yard.global/api/v1/get-events/?code='.trim(strip_tags($params['code']));

    if ($params['city'] != '') {
        $remote_url .= '&city='.trim(strip_tags($params['city']));
    }

    if ($params['country'] != '') {
        $remote_url .= '&country='.trim(strip_tags($params['country']));
    }

    if ($params['topic'] != '') {
        $remote_url .= '&topic='.trim(strip_tags($params['topic']));
    }

    $response = wp_remote_get($remote_url);

    if (is_wp_error($response)) {
        return '<p>Unable to retrieve events. Please try again later.</p>';
    }

    $response_body = json_decode(wp_remote_retrieve_body($response), true);

    if (empty($response_body) || !isset($response_body['events'])) {
        return '<p>No events found or invalid API response.</p>';
    }

    $events = $response_body['events'];

    if (empty($events)) {
        return '<p>No events found.</p>';
    }
    ?>
    
    <div class="yard-wrapper">
        <div class="events-container">
            <?php foreach($events as $key => $event):?>
                <a href="<?php echo esc_url($event['permalink']);?>" target="_blank" class="event-item">                
                    <?php if ($event['websitethumbnailhostname'] != '' && $event['websitethumbnailurl']):?>
                        <img src="<?php echo esc_html($event['websitethumbnailhostname']);?><?php echo esc_html($event['websitethumbnailurl']);?>">
                    <?php endif;?>
                    
                    <h2 class="event-title"><?php echo esc_html($event['title']);?></h2>
                    <span class="event-outputdate"><?php echo esc_html($event['outputdate']);?></span><br>
                    <span class="event-location">
                        <?php if($event['city']):?>
                            <?php echo esc_html($event['city']);?>
                            <?php if($event['country']):?>
                                (<?php echo esc_html($event['country']);?>)
                            <?php endif;?>
                            <?php if($event['offsite'] == '1'):?>
                                and virtual
                            <?php endif;?>
                        <?php else:?>
                            virtual
                        <?php endif;?>
                    </span><br>
                    </a>
            <?php endforeach;?>
        </div>

        <?php if (count($events) == 40):?>
            <!--a href="https://www.yard.global/events/?topic=web3" style="margin-top:1rem; padding: 0 1rem; display:block;" target="_blank">
                Find even more events on Yard. Search form
            </a-->
        <?php endif;?>

        <div class="events-copyright">
            This calendar is powered by <a href="https://www.yard.global" target="_blank"><img src="https://www.yard.global/wp-content/uploads/2024/09/yard-logo-dark.svg" style="height:30px; width:77px; margin-left:4px; margin-right:4px;"></a>  with generous support of sponsors. <a href="https://www.yard.global/events/integrate/?from=plugin" target="_blank">Integrate a Yard calendar</a>
        </div>
    </div>
    
    <?php
    /*
    echo "<pre>";
    var_dump( $events );
    echo "</pre>";
    */

    return $output;
}

function yard_events_shortcode($atts) {
    $atts = shortcode_atts(
        array(
            'code' => '', // Default value for 'code' parameter
            'city' => '',
            'country' => '',
            'topic' => ''
        ), 
        $atts, 
        'yard_plugin'
    );

    return yard_fetch_events($atts);
}
add_shortcode('yard_plugin', 'yard_events_shortcode');

